@@ -11,16 +11,16 @@
 #' @param ts_model_fn Univariate time series modelling function for the coefficients. Any
 #' model that works with the fable package is ok. Default is [fable::ARIMA()].
 #' @param coherent If TRUE, fitted models are stationary, other than for the case of
-#' a key variable taking the value `geometric_mean`. This is designed to work with
-#' vitals produced using \code{\link{make_pr}()}. Default is FALSE. It only works
-#' when `ts_model_fn` is \code{\link[fable]{ARIMA}()}.
+#' a key variable taking the value `geometric_mean` or `mean`. This is designed to work with
+#' vitals produced using \code{\link{make_pr}()} and \code{\link{make_sd}}.
+#' Default is FALSE. It only works when `ts_model_fn` is \code{\link[fable]{ARIMA}()}.
 #' @param ... Not used.
 #'
 #' @references Hyndman, R. J., and Ullah, S. (2007) Robust forecasting of
 #' mortality and fertility rates: a functional data approach.
 #' *Computational Statistics & Data Analysis*, 5, 4942-4956.
 #' <https://robjhyndman.com/publications/funcfor/>
-#' Hyndman, R. J., Booth, H., & Yasmeen, F. (2013). Coherent mortality
+#' @references Hyndman, R. J., Booth, H., & Yasmeen, F. (2013). Coherent mortality
 #' forecasting: the product-ratio method with functional time series models.
 #' *Demography*, 50(1), 261-283.
 #' <https://robjhyndman.com/publications/coherentfdm/>
@@ -35,17 +35,28 @@
 #' report(hu)
 #' autoplot(hu)
 #' @export
-FDM <- function(formula, order = 6, ts_model_fn = fable::ARIMA,
-                coherent = FALSE, ...) {
-  if(coherent & !identical(ts_model_fn, fable::ARIMA)) {
+FDM <- function(
+  formula,
+  order = 6,
+  ts_model_fn = fable::ARIMA,
+  coherent = FALSE,
+  ...
+) {
+  if (coherent & !identical(ts_model_fn, fable::ARIMA)) {
     stop("coherent = TRUE only works with ts_model_fn = fable::ARIMA")
   }
-  if(!coherent) {
+  if (!coherent) {
     coherent <- NULL
   }
   fd_model <- new_model_class("fdm", train = train_fdm)
-  new_model_definition(fd_model, !!enquo(formula),
-    order = order, ts_model_fn = ts_model_fn, coherent = coherent, ...)
+  new_model_definition(
+    fd_model,
+    !!enquo(formula),
+    order = order,
+    ts_model_fn = ts_model_fn,
+    coherent = coherent,
+    ...
+  )
 }
 
 train_fdm <- function(.data, specials, order, ts_model_fn, coherent, ...) {
@@ -55,7 +66,12 @@ train_fdm <- function(.data, specials, order, ts_model_fn, coherent, ...) {
   measures <- measured_vars(.data)
   measures <- measures[!(measures %in% c(agevar, vvar$population))]
   measures <- measures[1]
-  out <- fdm(.data, order = order, ts_model_fn = ts_model_fn, coherent = coherent)
+  out <- fdm(
+    .data,
+    order = order,
+    ts_model_fn = ts_model_fn,
+    coherent = coherent
+  )
 
   fitted <- out$data |>
     mutate(
@@ -80,23 +96,29 @@ train_fdm <- function(.data, specials, order, ts_model_fn, coherent, ...) {
 #' @rdname forecast
 #' @export
 
-forecast.FDM <- function(object, new_data = NULL, h = NULL, point_forecast = list(.mean = mean),
-  simulate = FALSE, bootstrap = FALSE, times = 5000, ...) {
-
-# simulation/bootstrap not actually used here as forecast.mdl_vtl_ts
-# handles this using generate() and forecast.FDM is never called.
-# The arguments are included to avoid a warning message.
+forecast.FDM <- function(
+  object,
+  new_data = NULL,
+  h = NULL,
+  point_forecast = list(.mean = mean),
+  simulate = FALSE,
+  bootstrap = FALSE,
+  times = 5000,
+  ...
+) {
+  # simulation/bootstrap not actually used here as forecast.mdl_vtl_ts
+  # handles this using generate() and forecast.FDM is never called.
+  # The arguments are included to avoid a warning message.
 
   # Forecast all beta series using stored models
   h <- length(unique(new_data[[index_var(new_data)]]))
   fc <- purrr::map(object$ts_model, function(x) {
-      forecast(x, h = h) |>
+    forecast(x, h = h) |>
       select(-.mean, -.model) |>
       as_tibble()
-    }
-  )
+  })
   indexvar <- index_var(object$model$by_t)
-  fc <- purrr::reduce(fc, left_join, by=indexvar)
+  fc <- purrr::reduce(fc, left_join, by = indexvar)
 
   # Create forecasts of response series
   agevar <- colnames(object$model$by_x)[1]
@@ -104,32 +126,38 @@ forecast.FDM <- function(object, new_data = NULL, h = NULL, point_forecast = lis
     left_join(object$model$by_x, by = agevar) |>
     left_join(fc, by = indexvar)
   fc$out <- fc$mean
-  for(i in seq_along(object$ts_model)) {
-    fc$out <- fc$out + fc[[paste0("beta", i)]] * fc[[paste0("phi",i)]]
+  for (i in seq_along(object$ts_model)) {
+    fc$out <- fc$out + fc[[paste0("beta", i)]] * fc[[paste0("phi", i)]]
   }
   fc |>
     pull(out)
 }
 
 #' @export
-generate.FDM <- function(x, new_data = NULL, h = NULL,
-  bootstrap = FALSE, times = 1,
-  forecast_fn, ...) {
+generate.FDM <- function(
+  x,
+  new_data = NULL,
+  h = NULL,
+  bootstrap = FALSE,
+  times = 1,
+  forecast_fn,
+  ...
+) {
   agevar <- age_var(new_data)
   indexvar <- index_var(new_data)
-  if(times != length(unique(new_data$.rep)))
+  if (times != length(unique(new_data$.rep))) {
     stop("We have a problem")
+  }
 
   # Simulate all beta series using stored models
   h <- length(unique(new_data[[index_var(new_data)]]))
   fc <- purrr::map(x$ts_models, function(x) {
-      out <- generate(x, h = h, bootstrap = bootstrap, times = times) |>
-        as_tibble()
-      out$.model <- out$.innov <- NULL
-      return(out)
-    }
-  )
-  fc <- purrr::reduce(fc, left_join, by=c(indexvar, ".rep"))
+    out <- generate(x, h = h, bootstrap = bootstrap, times = times) |>
+      as_tibble()
+    out$.model <- out$.innov <- NULL
+    return(out)
+  })
+  fc <- purrr::reduce(fc, left_join, by = c(indexvar, ".rep"))
   names(fc)[-(1:2)] <- names(x$ts_models)
 
   # Create simulations of response series
@@ -137,11 +165,11 @@ generate.FDM <- function(x, new_data = NULL, h = NULL,
     left_join(x$model$by_x, by = agevar) |>
     left_join(fc, by = c(indexvar, ".rep"))
   fc$out <- fc$mean
-  for(i in seq_along(x$ts_models)) {
-    fc$out <- fc$out + fc[[paste0("beta", i)]] * fc[[paste0("phi",i)]]
+  for (i in seq_along(x$ts_models)) {
+    fc$out <- fc$out + fc[[paste0("beta", i)]] * fc[[paste0("phi", i)]]
   }
   fc |>
-    select(.rep, sym(indexvar), !!agevar, .sim=out) |>
+    select(.rep, sym(indexvar), !!agevar, .sim = out) |>
     transmute(group_by_key(new_data), .sim)
 }
 
@@ -162,18 +190,18 @@ tidy.FDM <- function(x, ...) {
 report.FDM <- function(object, ...) {
   cat("\n")
   cat("Basis functions\n")
-  print(object$model$by_x, n=5)
+  print(object$model$by_x, n = 5)
   cat("\nCoefficients\n")
-  print(object$model$by_t, n=5)
+  print(object$model$by_t, n = 5)
   cat("\nTime series models\n")
   models <- names(object$ts_models)
-  for(i in seq_along(object$ts_models)) {
+  for (i in seq_along(object$ts_models)) {
     cat("  ", models[i], ": ")
     cat(model_sum(object$ts_model[[i]]$fit[[1]]), "\n")
   }
   cat("\nVariance explained\n  ")
-  cat(paste(round(object$model$varprop*100, 2), collapse=" + "))
-  cat(paste0(" = ", round(sum(object$model$varprop)*100, 2), "%\n"))
+  cat(paste(round(object$model$varprop * 100, 2), collapse = " + "))
+  cat(paste0(" = ", round(sum(object$model$varprop) * 100, 2), "%\n"))
 }
 
 #' @export
@@ -186,7 +214,11 @@ model_sum.FDM <- function(x) {
 time_components.FDM <- function(object, ...) {
   modelname <- attributes(object)$model
   object <- object |>
-    mutate(out = purrr::map(object[[modelname]], function(x){x$fit$model})) |>
+    mutate(
+      out = purrr::map(object[[modelname]], function(x) {
+        x$fit$model
+      })
+    ) |>
     as_tibble()
   object[[modelname]] <- NULL
   index <- index_var(object$out[[1]]$by_t)
@@ -194,17 +226,21 @@ time_components.FDM <- function(object, ...) {
   object$out <- lapply(object$out, function(x) as_tibble(x$by_t))
   object |>
     tidyr::unnest("out") |>
-    as_tsibble(index = index, key=all_of(keys))
+    as_tsibble(index = index, key = all_of(keys))
 }
 
 #' @export
 age_components.FDM <- function(object, ...) {
   modelname <- attributes(object)$model
   object <- object |>
-    mutate(out = purrr::map(object[[modelname]], function(x){x$fit$model})) |>
+    mutate(
+      out = purrr::map(object[[modelname]], function(x) {
+        x$fit$model
+      })
+    ) |>
     as_tibble()
   object[[modelname]] <- NULL
-  object$out  <- lapply(object$out, function(x) as_tibble(x$by_x))
+  object$out <- lapply(object$out, function(x) as_tibble(x$by_x))
   object |> tidyr::unnest("out")
 }
 
@@ -239,7 +275,7 @@ autoplot.FDM <- function(object, show_order = 2, ...) {
 # But assumes transformation already done
 
 fdm <- function(data, order = 6, ts_model_fn = fable::ARIMA, coherent = NULL) {
-  if(is.null(coherent)) {
+  if (is.null(coherent)) {
     coherent <- FALSE
   }
   # Grab variable names
@@ -256,7 +292,10 @@ fdm <- function(data, order = 6, ts_model_fn = fable::ARIMA, coherent = NULL) {
   mx <- data |>
     as_tibble() |>
     dplyr::select(all_of(c(indexvar, agevar, measures))) |>
-    tidyr::pivot_wider(values_from = all_of(measures), names_from = all_of(agevar))
+    tidyr::pivot_wider(
+      values_from = all_of(measures),
+      names_from = all_of(agevar)
+    )
   mx[[indexvar]] <- NULL
   mx <- as.matrix(mx)
   mx[mx == -Inf] <- NA
@@ -268,13 +307,14 @@ fdm <- function(data, order = 6, ts_model_fn = fable::ARIMA, coherent = NULL) {
   colnames(fits) <- year
   fits <- fits |>
     dplyr::mutate(Age = ages) |>
-    tidyr::pivot_longer(-Age, names_to = "Year", values_to = ".fitted") |>
-    dplyr::mutate(Year = as.integer(Year))
+    tidyr::pivot_longer(-Age, names_to = "Year", values_to = ".fitted")
+  colnames(fits)[1:2] <- c(agevar, indexvar)
+  fits[[indexvar]] <- as.numeric(fits[[indexvar]])
 
   # Add fitted values and residuals to original data
   output <- data |>
     as_tibble() |>
-    dplyr::left_join(fits, by = c("Year", "Age")) |>
+    dplyr::left_join(fits, by = c(indexvar, agevar)) |>
     as_vital(index = sym(indexvar), key = sym(agevar), .age = agevar)
 
   by_x <- as_tibble(y.pca$basis)
@@ -290,10 +330,13 @@ fdm <- function(data, order = 6, ts_model_fn = fable::ARIMA, coherent = NULL) {
   ts_coefs <- names(by_t)
   ts_coefs <- ts_coefs[grepl("beta", ts_coefs)]
   fits <- purrr::map(ts_coefs, function(x) {
-    if(coherent) {
+    if (coherent) {
       mod <- by_t |>
-        fabletools::model(fit = ts_model_fn(!!sym(x),
-          order_constraint = (p + q + P + Q <= 6) & (d + D == 0))
+        fabletools::model(
+          fit = ts_model_fn(
+            !!sym(x),
+            order_constraint = (p + q + P + Q <= 6) & (d + D == 0)
+          )
         )
     } else {
       mod <- by_t |>
@@ -341,13 +384,15 @@ fdpca <- function(X, order = 2, ngrid = 500) {
   # Standard error in mean estimate
   axse <- stats::approx(xx, sqrt(apply(yy, 1, stats::var) / n), xout = x)$y
   # Set up coeff and basis for order 0
-  coeff <- matrix(1, nrow=n, ncol=1)
-  basis <- matrix(stats::approx(xx, ax, xout = x)$y, ncol=1)
+  coeff <- matrix(1, nrow = n, ncol = 1)
+  basis <- matrix(stats::approx(xx, ax, xout = x)$y, ncol = 1)
   colnames(coeff)[1] <- colnames(basis)[1] <- "mean"
   if (order == 0) {
     return(list(
-      basis = basis, coeff = coeff,
-      v = rep(1, n), mean.se = axse
+      basis = basis,
+      coeff = coeff,
+      v = rep(1, n),
+      mean.se = axse
     ))
   }
   # Compute SVD
@@ -361,7 +406,8 @@ fdpca <- function(X, order = 2, ngrid = 500) {
   Phinormngrid <- matrix(NA, ngrid, order)
   delta <- xx[2] - xx[1]
   for (i in seq(order)) {
-    Phinorm[, i] <- stats::approx(xx, Phi[, i], xout = x)$y / delta /
+    Phinorm[, i] <- stats::approx(xx, Phi[, i], xout = x)$y /
+      delta /
       (sqrt(sum((stats::approx(xx, Phi[, i], xout = x)$y / delta)^2)))
     Phinormngrid[, i] <- stats::approx(x, Phinorm[, i], xout = xx)$y
   }
@@ -386,13 +432,15 @@ fdpca <- function(X, order = 2, ngrid = 500) {
 
   # Return results
   return(list(
-    basis = basis, coeff = coeff,
-    varprop = varprop[seq(order)], eigen_value = eigen_value,
-    v = v, mean.se = axse
+    basis = basis,
+    coeff = coeff,
+    varprop = varprop[seq(order)],
+    eigen_value = eigen_value,
+    v = v,
+    mean.se = axse
   ))
 }
 
 
-
 utils::globalVariables(c(".model", "out", "object", ".fitted", ".rep"))
 utils::globalVariables(c("p", "P", "d", "D", "q", "Q", "constant"))
