@@ -9,8 +9,8 @@
 #' @return vital object containing the age components from the model.
 #'
 #' @examples
-#' aus_mortality |>
-#'   dplyr::filter(State == "Victoria", Sex == "female") |>
+#' norway_mortality |>
+#'   dplyr::filter(Sex == "Female") |>
 #'   model(lee_carter = LC(log(Mortality))) |>
 #'   age_components()
 #'
@@ -30,20 +30,42 @@ age_components <- function(object, ...) {
 #' @return tsibble object containing the time components from the model.
 #'
 #' @examples
-#' aus_mortality |>
-#'   dplyr::filter(State == "Victoria", Sex == "female") |>
+#' norway_mortality |>
+#'   dplyr::filter(Sex == "Female") |>
 #'   model(lee_carter = LC(log(Mortality))) |>
 #'   time_components()
-#'
 #' @export
 time_components <- function(object, ...) {
   UseMethod("time_components")
 }
 
+#' Extract cohort components from a model
+#'
+#' For a mable with a single model column, return the model components
+#' that are indexed by birth year of the cohort.
+#'
+#' @param object A vital mable object with a single model column.
+#' @param ... Not currently used.
+#'
+#' @return tsibble object containing the cohort components from the model.
+#'
+#' @examples
+#' norway_mortality |>
+#'   dplyr::filter(Sex == "Male", Age > 50, Year > 1960) |>
+#'   model(apc = APC(Mortality)) |>
+#'   cohort_components()
+#' @export
+cohort_components <- function(object, ...) {
+  UseMethod("cohort_components")
+}
+
+
 #' @export
 time_components.mdl_vtl_df <- function(object, ...) {
   if (length(mable_vars(object)) > 1) {
-    stop("Extracting components is only supported for individual models. Please use `dplyr::select()` to choose one model column.")
+    stop(
+      "Extracting components is only supported for individual models. Please use `dplyr::select()` to choose one model column."
+    )
   }
   model <- mable_vars(object)
   class(object) <- c(class(object[[model]][[1]]$fit), class(object)[-1])
@@ -53,9 +75,23 @@ time_components.mdl_vtl_df <- function(object, ...) {
 #' @export
 age_components.mdl_vtl_df <- function(object, ...) {
   if (length(mable_vars(object)) > 1) {
-    stop("Extracting components is only supported for individual models. Please use `dplyr::select()` to choose one model column.")
+    stop(
+      "Extracting components is only supported for individual models. Please use `dplyr::select()` to choose one model column."
+    )
   }
   model <- mable_vars(object)
   class(object) <- c(class(object[[model]][[1]]$fit), class(object))
   age_components(object, ...)
 }
+
+#' @export
+cohort_components.mdl_vtl_df <- function(object, ...) {
+  if (length(mable_vars(object)) > 1) {
+    stop(
+      "Extracting components is only supported for individual models. Please use `dplyr::select()` to choose one model column."
+    )
+  }
+  model <- mable_vars(object)
+  class(object) <- c(class(object[[model]][[1]]$fit), class(object)[-1])
+  cohort_components(object, ...)
+}
