@@ -1,13 +1,17 @@
 test_that("Coherent calculatons", {
   # Product/ratio
-  orig_data <- aus_mortality |>
-   dplyr::filter(Year > 2015, Sex != "total", Code == "NSW")
-  pr <- orig_data |> make_pr(Mortality) |> undo_pr(Mortality)
+  orig_data <- norway_mortality |>
+    dplyr::filter(Year > 2015, Sex != "Total")
+  pr <- orig_data |>
+    make_pr(Mortality) |>
+    undo_pr(Mortality)
   expect_equal(orig_data, pr)
   # Mean/difference
   mig <- net_migration(norway_mortality, norway_births) |>
-     dplyr::filter(Sex != "Total")
-  sd <- mig |> make_sd(NetMigration) |> undo_sd(NetMigration)
+    dplyr::filter(Sex != "Total")
+  sd <- mig |>
+    make_sd(NetMigration) |>
+    undo_sd(NetMigration)
   expect_equal(mig, sd)
 })
 
@@ -25,20 +29,16 @@ all_stationary <- function(object) {
 }
 
 test_that("Coherent functional data model", {
-  pr <- aus_mortality |>
-    dplyr::filter(State == "Victoria", Sex != "total", Year > 1950) |>
+  pr <- norway_mortality |>
+    dplyr::filter(Sex != "Total", Year > 2000) |>
     make_pr(Mortality)
   pr1 <- pr |>
     model(hu = FDM(log(Mortality), coherent = TRUE))
   stationary <- purrr::map_lgl(pr1$hu, all_stationary)
-  expect_identical(pr1$Sex[stationary], c("female","male"))
+  expect_identical(pr1$Sex[stationary], c("Female", "Male"))
   expect_identical(pr1$Sex[!stationary], "geometric_mean")
   pr2 <- pr |>
     model(hu = FDM(log(Mortality), coherent = FALSE))
   stationary <- purrr::map_lgl(pr2$hu, all_stationary)
-  expect_true(all(!stationary))
+  expect_true(!all(stationary))
 })
-
-
-
-
