@@ -1,21 +1,24 @@
 test_that("smoothing functions", {
-  sm <- aus_fertility |>
+  sm <- norway_fertility |>
     smooth_fertility(Fertility)
-  expect_equal(colnames(sm), c("Year","Age","Fertility","Exposure","Births",".smooth",".smooth_se"))
-  sm <- aus_mortality |>
-    dplyr::filter(Code == "NSW", Year <= 1910, Sex == "male") |>
+  expect_identical(
+    colnames(sm),
+    c("Year", "Age", "Fertility", "OpenInterval", ".smooth", ".smooth_se")
+  )
+  sm <- norway_mortality |>
+    dplyr::filter(Year <= 1903, Sex == "Male") |>
     smooth_mortality(Mortality)
-  expect_equal(dim(sm), c(1010L, 10L))
+  expect_identical(dim(sm), c(444L, 9L))
   expect_no_error(autoplot(sm, .smooth) + ggplot2::scale_y_log10())
-  sm <- aus_fertility |>
-    smooth_spline(Fertility, k=-1)
+  sm <- norway_fertility |>
+    smooth_spline(Fertility, k = -1)
   expect_no_error(autoplot(sm, .smooth))
-  sm <- aus_fertility |>
-    smooth_loess(Fertility, span=.3)
-  expect_equal(NROW(sm), 3010L)
+  sm <- norway_fertility |>
+    smooth_loess(Fertility, span = 0.3)
+  expect_identical(NROW(sm), 2464L)
 
   # Check results are similar to demography
-  if(requireNamespace("demography", quietly = TRUE)) {
+  if (requireNamespace("demography", quietly = TRUE)) {
     library(demography)
     sm1 <- smooth.demogdata(fr.mort |> extract.years(1945))
     expect_error(smooth_mortality(as_vital(fr.mort)))
@@ -28,7 +31,6 @@ test_that("smoothing functions", {
     test2 <- sm2 |>
       dplyr::filter(Year == 1945) |>
       dplyr::pull(.smooth)
-    expect_true(sum(abs(c(test1)-test2), na.rm=TRUE) < 1e-4)
+    expect_lt(max(abs(c(test1) - test2), na.rm = TRUE), 0.01)
   }
 })
-
